@@ -50,7 +50,7 @@ scaffold_output <- function(name, edit = interactive()){
   create_directory("inst/packer", recurse = TRUE)
 
   # install dev webpack + cli
-  webpack_install()
+  core_deps_install()
 
   # edit package.json
   engine_add_scripts()
