@@ -10,10 +10,12 @@ test_that("Ambiorix Bare", {
   # test bare
   pkg <- create_tmp_ambiorix()
   setwd(pkg)
+  on.exit({
+    setwd(wd)
+    delete_tmp_package(pkg)
+  })
   expect_output(scaffold_ambiorix(edit = FALSE))
   expect_message(bundle())
-  setwd(wd)
-  delete_tmp_package(pkg)
 })
 
 test_that("Ambiorix Vue", {
@@ -24,8 +26,10 @@ test_that("Ambiorix Vue", {
   # test bare
   pkg <- create_tmp_ambiorix()
   setwd(pkg)
+  on.exit({
+    setwd(wd)
+    delete_tmp_package(pkg)
+  })
   expect_output(scaffold_ambiorix(vue = TRUE, edit = FALSE))
   expect_message(bundle())
-  setwd(wd)
-  delete_tmp_package(pkg)
 })
